@@ -11,11 +11,12 @@
 ------------      -------    --------    -----------
 2020-04-09 19:12   肖林朋      1.0         数据处理封装闭包管理器
 """
-from datafushion.args import ArgStruct
+from datafushion.args import ArgStruct, FileExtractFormatEnum
 from datafushion.parse_utils import parse_file_2_map_list
 
 from contextlib import contextmanager
 import json
+import csv
 import sys
 
 
@@ -50,7 +51,7 @@ class HandleDataSet(object):
 
 
 @contextmanager
-def operation(reverse_mapping=False):
+def operation(reverse_mapping=False, output_type=FileExtractFormatEnum.JSON.value):
     """
     数据处理封装
     :return:
@@ -98,8 +99,13 @@ def operation(reverse_mapping=False):
         :param output_path:  输出路径
         :return:
         """
-        with open(output_path, "w", encoding='utf-8') as f:
-            json.dump(data_result, f)
+        if output_type == FileExtractFormatEnum.JSON.value:
+            with open(output_path, "w", encoding='utf-8') as f:
+                json.dump(data_result, f, ensure_ascii=False)
+        elif output_type == FileExtractFormatEnum.CSV.value:
+            with open(output_path, "w", encoding='utf-8', newline='') as f:
+                writer = csv.writer(f)
+                writer.writerows(data_result)
 
 
     destruction = destruction()  # type: HandleDataSet
